﻿<%@ WebHandler Language="C#" Class="PublicHolidays" %>

using System;
using System.Web;
using System.Xml.Serialization;
using System.IO;
using System.Text;
using Newtonsoft.Json;

public class PublicHolidays : IHttpHandler {
    
    public void ProcessRequest (HttpContext context) {
        int y = 0;
        int m = 0;
        int d = 0;

        string ys = context.Request.QueryString["year"];
        string ms = context.Request.QueryString["month"];
        string ds = context.Request.QueryString["day"];
        string js = context.Request.QueryString["json"];
        bool valid = ValidateArguments(ys, ms, ds, out y, out m, out d);

        object resultObject = null;
        XmlResult result = new XmlResult();
        if (valid)
        {
            PublicHolidaysService service = new PublicHolidaysService();
            if ((m == 0) && (d == 0))
            {
                resultObject = service.GetPublicHolidaysByYear(y);
                result.HolidayInfos = (HolidayInfo[])resultObject;
            }
            else if (d == 0)
            {
                resultObject = service.GetPublicHolidaysByMonth(y, m);
                result.HolidayInfos = (HolidayInfo[])resultObject;
            }
            else
            {
                resultObject = service.GetPublicHolidayNames(y, m, d);
                result.HolidayNames = (HolidayName[])resultObject;
            }
        }
        if (String.IsNullOrEmpty(js))
        {
            XmlSerializer serializer = new XmlSerializer(typeof(XmlResult), "");
            context.Response.ContentType = "text/xml";
            serializer.Serialize(context.Response.Output, result);
        }
        else
        {
            string json = JavaScriptConvert.SerializeObject(resultObject);
            context.Response.ContentType = "application/json";
            context.Response.Write(json);
        }
        context.Response.End();
    }

    private bool ValidateArguments(string yearString, string monthString, string dayString, out int year, out int month, out int day)
    {
        year = 0;
        month = 0;
        day = 0;
        int.TryParse(yearString, out year);
        if ((year < 1948) || (year > 2050))
        {
            return false;
        }
        if (monthString != null)
        {
            int.TryParse(monthString, out month);
            if ((month < 1) || (month > 12))
            {
                return false;
            }
        }
        if (dayString != null)
        {
            if (month == 0)
            {
                return false;
            }
            int.TryParse(dayString, out day);
            if ((day < 1) || (day > DateTime.DaysInMonth(year, month)))
            {
                return false;
            }
        }
        return true;
    }

    public bool IsReusable {
        get {
            return true;
        }
    }

}